@@ -1,15 +1,17 @@
 package Video::DVDRip::CheckedEntry;
 
+# use strict;
+
 use base Gtk::Entry;
 
 sub is_number			{ shift->{is_number}			}
 sub is_min			{ shift->{is_min}			}
 sub is_max			{ shift->{is_max}			}
 sub is_frame_or_timecode	{ shift->{is_frame_or_timecode}		}
-
 sub may_empty			{ shift->{may_empty}			}
 sub may_fractional		{ shift->{may_fractional}		}
 sub may_negative		{ shift->{may_negative}			}
+sub cond			{ shift->{cond}				}
 
 sub set_is_number		{ shift->{is_number}		= $_[1]	}
 sub set_is_min			{ shift->{is_min}		= $_[1]	}
@@ -18,7 +20,7 @@ sub set_may_empty		{ shift->{may_empty}		= $_[1]	}
 sub set_may_fractional		{ shift->{may_fractional}	= $_[1]	}
 sub set_may_negative		{ shift->{may_negative}		= $_[1]	}
 sub set_is_frame_or_timecode	{ shift->{is_frame_or_timecode}	= $_[1]	}
-
+sub set_cond			{ shift->{cond}			= $_[1]	}
 
 sub old_val			{ shift->{old_val}			}
 sub set_old_val			{ shift->{old_val}		= $_[1]	}
@@ -28,8 +30,8 @@ sub new {
 	my ($max_length, %par) = @_;
 	my  ($is_number, $is_min, $is_max, $may_empty, $may_fractional) =
 	@par{'is_number','is_min','is_max','may_empty','may_fractional'};
-	my  ($may_negative, $is_frame_or_timecode) =
-	@par{'may_negative','is_frame_or_timecode'};
+	my  ($may_negative, $is_frame_or_timecode, $cond) =
+	@par{'may_negative','is_frame_or_timecode','cond'};
 
 	my $self = bless $class->SUPER::new ($max_length), $class;
 
@@ -40,6 +42,7 @@ sub new {
 	$self->set_is_max ($is_max);
 	$self->set_may_negative ($may_negative);
 	$self->set_is_frame_or_timecode ($is_frame_or_timecode);
+	$self->set_cond($cond);
 
 	$self->connect_check_signals;
 
@@ -68,21 +71,24 @@ sub check_value {
 	my $val = $self->get_text;
 
 	my $restore;
+	my $cond = $self->cond;
+	if ( $cond ) {
+		$restore = ! &$cond($val);
+	}
 
 	if ( not $self->may_empty and $val eq '' ) {
 		$restore = 1;
 	}
 
 	if ( not $restore and $self->is_number and $val ne '' ) {
-		my $new_val = 0 + $val;
-		if ( $new_val ne $val ) {
-			$restore = 1;
-		} elsif ( not $self->may_fractional and $val =~ /\./ ){
-			$restore = 1;
+		if ( $self->may_fractional ) {
+			$restore = 1 if $val !~ /^-?\d+(\.\d+)?$/;
+		} else {
+			$restore = 1 if $val !~ /^-?\d+$/;
 		}
-		$restore = 1 if $self->is_min and $new_val < $self->is_min;
-		$restore = 1 if $self->is_max and $new_val > $self->is_max;
-		$restore = 1 if not $self->may_negative and $new_val < 0;
+		$restore = 1 if defined $self->is_min and $val < $self->is_min;
+		$restore = 1 if defined $self->is_max and $val > $self->is_max;
+		$restore = 1 if not $self->may_negative and $val < 0;
 	}
 
 	if ( not $restore and $self->is_frame_or_timecode ) {
