@@ -1,7 +1,8 @@
-# $Id: Project.pm,v 1.33.2.2 2002/12/02 18:22:00 joern Exp $
+# $Id: Project.pm,v 1.41 2003/01/28 20:19:57 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
+# All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
@@ -127,7 +128,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.33.2.2 2002/12/02 18:22:00 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.41 2003/01/28 20:19:57 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -144,7 +145,9 @@ sub backup_copy {
 	my $self = shift; $self->trace_in;
 	
 	my $filename = $self->snap_dir."/backup.rip";
+	my $last_save_data = $self->last_saved_data;
 	$self->save ( filename => $filename );
+	$self->set_last_saved_data($last_save_data);
 	
 	1;
 }
@@ -177,14 +180,15 @@ sub changed {
 	my $actual_data_sref = $self->get_save_data;
 	my $saved_data_sref  = $self->last_saved_data;
 
+
 	my $actual = join ("\n", map { $_.="," if !/,$/;$_ }
 				 sort split (/\n/, $$actual_data_sref));
 	my $saved  = join ("\n", map { $_.="," if !/,$/;$_ }
 				 sort split (/\n/, $$saved_data_sref));
 
 	if ( $self->debug_level ) {
-		open (DBG,">/tmp/saved.txt"); print FOO $saved; close FOO;
-		open (DBG,">/tmp/actual.txt"); print FOO $actual; close FOO;
+		open (DBG,">/tmp/saved.txt"); print DBG $saved; close DBG;
+		open (DBG,">/tmp/actual.txt"); print DBG $actual; close DBG;
 	}
 
 	return $actual ne $saved;
@@ -205,7 +209,8 @@ sub load {
 	croak "File is no dvd::rip file"
 		if $data !~ /This file was generated by Video::DVDRip/;
 
-	my ($version, undef, $pre) = $data =~ /DVDRip Version (\d+\.\d+)(_(\d+))?/;
+	my ($version, undef, $pre) =  $data =~ /DVDRip Version (\d+\.\d+)(_(\d+))?/;
+	my ($major, $minor, $patch) = $data =~ /DVDRip Version (\d+)\.(\d+)\.(\d+)/;
 
 	my $project;
 	$project = eval($data);
@@ -213,17 +218,21 @@ sub load {
 
 	bless $project, ref($self);
 
+	my $save_data = $project->get_save_data;
+
 	$self->convert_from_old_version (
 		project => $project,
 		version => $version,
 		pre     => $pre,
+		major   => $major,
+		minor   => $minor,
+		patch   => $patch,
 	);
 
 	%{$self} = %{$project};
 
 	$self->content->set_project ($self);
-
-	$self->set_last_saved_data ($self->get_save_data);
+	$self->set_last_saved_data ($save_data);
 
 	1;
 }
@@ -282,122 +291,6 @@ sub dvd_mount_dir {
 	return $dir;
 }
 
-sub convert_from_old_version {
-	my $self = shift;
-	my %par = @_;
-	my  ($project, $version, $pre) =
-	@par{'project','version','pre'};
-
-	if ( $version < 0.45 or ( $version == 0.45 and
-	     defined $pre and $pre < 4 ) ) {
-	     	$self->convert_audio_tracks_0_45_04 (
-			project => $project,
-		);
-	}
-
-	if ( $version < 0.47 or ( $version == 0.47 and
-	     defined $pre and $pre < 2 ) ) {
-	     	$self->set_audio_bitrates_0_47_02 (
-			project => $project,
-		);
-	}
-
-	1;
-}
-
-sub convert_audio_tracks_0_45_04 {
-	my $self = shift;
-	my %par = @_;
-	my ($project) = @par{'project'};
-
-	print "[auto-conversion] Import audio configuration (0.45_04)\n";
-
-	$project->set_convert_message (
-		"WARNING: converted audio tracks to new data structure\n".
-		"of version 0.45_04. After saving the project file you\n".
-		"can't use it with an older version anymore!. Consider\n".
-		"making a backup copy before saving!"
-	);
-
-	foreach my $title ( values %{$project->content->titles} ) {
-		my $old_tracks = $title->audio_tracks;
-		my @probe_tracks;
-		my @tc_tracks;
-		my $i = 0;
-		foreach my $old ( @{$old_tracks} ) {
-			my $probe_track = Video::DVDRip::ProbeAudio->new (
-				type		=> $old->{type},
-				lang		=> $old->{lang},
-				channels	=> $old->{channels},
-				bitrate		=> $old->{bitrate},
-				sample_rate	=> $old->{sample_rate},
-				volume_rescale  => $old->{scan_result}
-						       ->{volume_rescale},
-				scan_output	=> $old->{scan_result}
-						       ->{scan_output},
-			);
-
-			my $tc_track = Video::DVDRip::Audio->new (
-				tc_nr => $i
-			);
-
-			$tc_track->set_tc_option_n (
-				$old->{tc_option_n}
-			);
-			$tc_track->set_tc_volume_rescale (
-				$old->{tc_volume_rescale}
-			);
-
-			if ( $i == $title->{audio_channel} ) {
-				$tc_track->set_tc_target_track(0);
-				$tc_track->set_tc_audio_codec (
-					$title->{tc_ac3_passthrough} ? "ac3" : "mp3"
-				);
-				$tc_track->set_tc_mp3_quality (
-					$title->{tc_mp3_quality}
-				);
-				$tc_track->set_tc_audio_filter (
-					$title->{tc_use_drc} ? 'a52drc' : 'rescale',
-				);
-				$tc_track->set_tc_bitrate (
-					$title->{tc_audio_bitrate}
-				);
-			}
-			push @probe_tracks, $probe_track;
-			push @tc_tracks,    $tc_track;
-
-			++$i;
-		}
-
-		$title->probe_result->set_audio_tracks ( \@probe_tracks );
-		$title->set_tc_audio_tracks ( \@tc_tracks );
-	}
-	
-	1;
-}
-
-sub set_audio_bitrates_0_47_02 {
-	my $self = shift;
-	my %par = @_;
-	my ($project) = @par{'project'};
-
-	print "[auto-conversion] Setting new audio bitrate attributes (0.47_02)\n";
-
-	foreach my $title ( values %{$project->content->titles} ) {
-		my $audio_info = $title->audio_tracks;
-		my $i = 0;
-		foreach my $audio ( @{$title->tc_audio_tracks} ) {
-			$audio->set_tc_mp2_bitrate ( $audio->{tc_bitrate} );
-			$audio->set_tc_mp3_bitrate ( $audio->{tc_bitrate} );
-			$audio->set_tc_ogg_bitrate ( $audio->{tc_bitrate} );
-			$audio->set_tc_ac3_bitrate ( $audio_info->[$i]->bitrate );
-			++$i;
-		}
-	}
-
-	1;
-}
-
 sub copy_ifo_files {
 	my $self = shift;
 
@@ -487,4 +380,45 @@ sub umount_dvd {
 	1;
 }
 
+sub convert_from_old_version {
+	my $self = shift;
+	my %par = @_;
+	my  ($project, $version, $pre, $major, $minor, $patch) =
+	@par{'project','version','pre','major','minor','patch'};
+
+	if ( $version < 0.45 or ( $version == 0.45 and
+	     defined $pre and $pre < 4 ) ) {
+	     	require Video::DVDRip::Convert;
+	     	Video::DVDRip::Convert->convert_audio_tracks_0_45_04 (
+			project => $project,
+		);
+	}
+
+	if ( $version < 0.47 or ( $version == 0.47 and
+	     defined $pre and $pre < 2 ) ) {
+	     	require Video::DVDRip::Convert;
+	     	Video::DVDRip::Convert->set_audio_bitrates_0_47_02 (
+			project => $project,
+		);
+	}
+	
+	$version = $major*10000+$minor*100+$patch;
+
+	if ( $version < 4900 ) {
+	     	require Video::DVDRip::Convert;
+		Video::DVDRip::Convert->convert_container_0_49_1 (
+			project => $project,
+		);
+	}
+
+	if ( $version < 4902 ) {
+	     	require Video::DVDRip::Convert;
+		Video::DVDRip::Convert->convert_0_49_2 (
+			project => $project,
+		);
+	}
+	
+	1;
+}
+
 1;
